Add av1 prefix to inv_txfm_add

Change-Id: Id7cbb89ba344770297ef42bf1b09a2b9ba5a1378
diff --git a/av1/common/idct.c b/av1/common/idct.c
index 092247e..cb1817d 100644
--- a/av1/common/idct.c
+++ b/av1/common/idct.c
@@ -2787,8 +2787,8 @@
 #endif  // CONFIG_TX64X64
 #endif  // CONFIG_AOM_HIGHBITDEPTH
 
-void inv_txfm_add(const tran_low_t *input, uint8_t *dest, int stride,
-                  INV_TXFM_PARAM *inv_txfm_param) {
+void av1_inv_txfm_add(const tran_low_t *input, uint8_t *dest, int stride,
+                      INV_TXFM_PARAM *inv_txfm_param) {
   const TX_TYPE tx_type = inv_txfm_param->tx_type;
   const TX_SIZE tx_size = inv_txfm_param->tx_size;
   const int eob = inv_txfm_param->eob;
@@ -2837,8 +2837,8 @@
 }
 
 #if CONFIG_AOM_HIGHBITDEPTH
-void highbd_inv_txfm_add(const tran_low_t *input, uint8_t *dest, int stride,
-                         INV_TXFM_PARAM *inv_txfm_param) {
+void av1_highbd_inv_txfm_add(const tran_low_t *input, uint8_t *dest, int stride,
+                             INV_TXFM_PARAM *inv_txfm_param) {
   const TX_TYPE tx_type = inv_txfm_param->tx_type;
   const TX_SIZE tx_size = inv_txfm_param->tx_size;
   const int eob = inv_txfm_param->eob;
diff --git a/av1/common/idct.h b/av1/common/idct.h
index 8f1eea1..a6b82c8 100644
--- a/av1/common/idct.h
+++ b/av1/common/idct.h
@@ -76,8 +76,8 @@
                             int eob, TX_TYPE tx_type);
 void av1_inv_txfm_add_32x32(const tran_low_t *input, uint8_t *dest, int stride,
                             int eob, TX_TYPE tx_type);
-void inv_txfm_add(const tran_low_t *input, uint8_t *dest, int stride,
-                  INV_TXFM_PARAM *inv_txfm_param);
+void av1_inv_txfm_add(const tran_low_t *input, uint8_t *dest, int stride,
+                      INV_TXFM_PARAM *inv_txfm_param);
 #if CONFIG_AOM_HIGHBITDEPTH
 void av1_highbd_iwht4x4_add(const tran_low_t *input, uint8_t *dest, int stride,
                             int eob, int bd);
@@ -104,8 +104,8 @@
 void av1_highbd_inv_txfm_add_32x32(const tran_low_t *input, uint8_t *dest,
                                    int stride, int eob, int bd,
                                    TX_TYPE tx_type);
-void highbd_inv_txfm_add(const tran_low_t *input, uint8_t *dest, int stride,
-                         INV_TXFM_PARAM *inv_txfm_param);
+void av1_highbd_inv_txfm_add(const tran_low_t *input, uint8_t *dest, int stride,
+                             INV_TXFM_PARAM *inv_txfm_param);
 #endif  // CONFIG_AOM_HIGHBITDEPTH
 #ifdef __cplusplus
 }  // extern "C"
diff --git a/av1/decoder/decodeframe.c b/av1/decoder/decodeframe.c
index 6b224c7..8da74ba 100644
--- a/av1/decoder/decodeframe.c
+++ b/av1/decoder/decodeframe.c
@@ -336,10 +336,10 @@
 #if CONFIG_AOM_HIGHBITDEPTH
   if (xd->cur_buf->flags & YV12_FLAG_HIGHBITDEPTH) {
     inv_txfm_param.bd = xd->bd;
-    highbd_inv_txfm_add(dqcoeff, dst, stride, &inv_txfm_param);
+    av1_highbd_inv_txfm_add(dqcoeff, dst, stride, &inv_txfm_param);
   } else {
 #endif  // CONFIG_AOM_HIGHBITDEPTH
-    inv_txfm_add(dqcoeff, dst, stride, &inv_txfm_param);
+    av1_inv_txfm_add(dqcoeff, dst, stride, &inv_txfm_param);
 #if CONFIG_AOM_HIGHBITDEPTH
   }
 #endif  // CONFIG_AOM_HIGHBITDEPTH
diff --git a/av1/encoder/encodemb.c b/av1/encoder/encodemb.c
index 23607e2..32b9986 100644
--- a/av1/encoder/encodemb.c
+++ b/av1/encoder/encodemb.c
@@ -753,11 +753,11 @@
 #if CONFIG_AOM_HIGHBITDEPTH
   if (xd->cur_buf->flags & YV12_FLAG_HIGHBITDEPTH) {
     inv_txfm_param.bd = xd->bd;
-    highbd_inv_txfm_add(dqcoeff, dst, pd->dst.stride, &inv_txfm_param);
+    av1_highbd_inv_txfm_add(dqcoeff, dst, pd->dst.stride, &inv_txfm_param);
     return;
   }
 #endif  // CONFIG_AOM_HIGHBITDEPTH
-  inv_txfm_add(dqcoeff, dst, pd->dst.stride, &inv_txfm_param);
+  av1_inv_txfm_add(dqcoeff, dst, pd->dst.stride, &inv_txfm_param);
 }
 
 #if CONFIG_VAR_TX
@@ -1078,12 +1078,12 @@
 #if CONFIG_AOM_HIGHBITDEPTH
     inv_txfm_param.bd = xd->bd;
     if (xd->cur_buf->flags & YV12_FLAG_HIGHBITDEPTH) {
-      highbd_inv_txfm_add(dqcoeff, dst, dst_stride, &inv_txfm_param);
+      av1_highbd_inv_txfm_add(dqcoeff, dst, dst_stride, &inv_txfm_param);
     } else {
-      inv_txfm_add(dqcoeff, dst, dst_stride, &inv_txfm_param);
+      av1_inv_txfm_add(dqcoeff, dst, dst_stride, &inv_txfm_param);
     }
 #else
-    inv_txfm_add(dqcoeff, dst, dst_stride, &inv_txfm_param);
+    av1_inv_txfm_add(dqcoeff, dst, dst_stride, &inv_txfm_param);
 #endif  // CONFIG_AOM_HIGHBITDEPTH
 
     *(args->skip) = 0;
@@ -1124,7 +1124,7 @@
 #error
 
 #else
-  inv_txfm_add(dqcoeff, dst, dst_stride, &inv_txfm_param);
+  av1_inv_txfm_add(dqcoeff, dst, dst_stride, &inv_txfm_param);
 #endif
 #endif  // #if !CONFIG_PVQ
 
diff --git a/av1/encoder/rdopt.c b/av1/encoder/rdopt.c
index 8eac058..d37104a 100644
--- a/av1/encoder/rdopt.c
+++ b/av1/encoder/rdopt.c
@@ -1336,7 +1336,7 @@
         inv_txfm_param.bd = xd->bd;
         aom_highbd_convolve_copy(dst, dst_stride, recon, MAX_TX_SIZE, NULL, 0,
                                  NULL, 0, bsw, bsh, xd->bd);
-        highbd_inv_txfm_add(dqcoeff, recon, MAX_TX_SIZE, &inv_txfm_param);
+        av1_highbd_inv_txfm_add(dqcoeff, recon, MAX_TX_SIZE, &inv_txfm_param);
       } else
 #endif  // CONFIG_AOM_HIGHBITDEPTH
       {
@@ -1349,7 +1349,7 @@
         for (j = 0; j < bsh; j++)
           for (i = 0; i < bsw; i++) recon[j * MAX_TX_SIZE + i] = 0;
 #endif  // !CONFIG_PVQ
-        inv_txfm_add(dqcoeff, recon, MAX_TX_SIZE, &inv_txfm_param);
+        av1_inv_txfm_add(dqcoeff, recon, MAX_TX_SIZE, &inv_txfm_param);
       }
 #if CONFIG_DAALA_DIST
       if (plane == 0) {
@@ -1451,7 +1451,7 @@
                  &this_rd_stats.dist, &this_rd_stats.sse);
     } else {
       // Note that the encode block_intra call above already calls
       // inv_txfm_add, so we can't just call dist_block here.
       const BLOCK_SIZE tx_bsize = txsize_to_bsize[tx_size];
       const aom_variance_fn_t variance = args->cpi->fn_ptr[tx_bsize].vf;
       const struct macroblock_plane *const p = &x->plane[plane];
@@ -3894,12 +3894,13 @@
 #if CONFIG_AOM_HIGHBITDEPTH
     if (xd->cur_buf->flags & YV12_FLAG_HIGHBITDEPTH) {
       inv_txfm_param.bd = xd->bd;
-      highbd_inv_txfm_add(dqcoeff, rec_buffer, MAX_TX_SIZE, &inv_txfm_param);
+      av1_highbd_inv_txfm_add(dqcoeff, rec_buffer, MAX_TX_SIZE,
+                              &inv_txfm_param);
     } else {
-      inv_txfm_add(dqcoeff, rec_buffer, MAX_TX_SIZE, &inv_txfm_param);
+      av1_inv_txfm_add(dqcoeff, rec_buffer, MAX_TX_SIZE, &inv_txfm_param);
     }
 #else   // CONFIG_AOM_HIGHBITDEPTH
-    inv_txfm_add(dqcoeff, rec_buffer, MAX_TX_SIZE, &inv_txfm_param);
+    av1_inv_txfm_add(dqcoeff, rec_buffer, MAX_TX_SIZE, &inv_txfm_param);
 #endif  // CONFIG_AOM_HIGHBITDEPTH
 
     if (txb_w + blk_col > max_blocks_wide ||
@@ -6638,7 +6639,7 @@
                   for (i2 = 0; i2 < 4; i2++) dst[j2 * dst_stride + i2] = 0;
               }
 #endif  // CONFIG_PVQ
-              inv_txfm_add(dqcoeff, dst, dst_stride, &inv_txfm_param);
+              av1_inv_txfm_add(dqcoeff, dst, dst_stride, &inv_txfm_param);
             }
           }
         }
@@ -1451,7 +1451,7 @@
     } else {
       // Note that the encode block_intra call above already calls
-      // inv_txfm_add, so we can't just call dist_block here.
+      // av1_inv_txfm_add, so we can't just call dist_block here.
       const BLOCK_SIZE tx_bsize = txsize_to_bsize[tx_size];
       const aom_variance_fn_t variance = args->cpi->fn_ptr[tx_bsize].vf;